﻿/*----------------------------------------------------------------
//  <copyright file="CommonController.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-17 19:06</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.AspNetCore.VerifyCode;
using EaCloud.Authorization.Modules;
using EaCloud.Drawing;
using EaCloud.Reflection;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using System;
using System.ComponentModel;
using System.Drawing;
using System.Dynamic;
using System.Linq;
using System.Reflection;
using AssemblyExtensions = EaCloud.Reflection.AssemblyExtensions;

namespace EaCloud.Template.Svc.Controllers
{
    #region "网站-通用"
    /// <summary>
    /// 网站-通用
    /// </summary>
    [Description("网站-通用")]
    [ModuleInfo(Order = 3)]
    public class CommonController : SiteApiControllerBase
    {
        //字段
        private readonly IVerifyCodeService _verifyCodeService;

        #region "构造函数"
        #region "初始化一个 网站-通用 的新实例"
        /// <summary>
        /// 初始化一个 网站-通用 的新实例
        /// </summary>
        /// <param name="verifyCodeService"></param>
        public CommonController(IVerifyCodeService verifyCodeService)
        {
            _verifyCodeService = verifyCodeService;
        }
        #endregion

        #endregion

        #region "Action方法"
        #region "获取验证码图片"
        /// <summary>
        /// 获取验证码图片
        /// </summary>
        /// <returns>验证码图片文件</returns>
        [HttpGet]
        [ModuleInfo]
        [Description("验证码")]
        public string VerifyCode()
        {
            ValidateCoder coder = new()
            {
                RandomColor = true,
                RandomItalic = true,
                RandomLineCount = 7,
                RandomPointPercent = 10,
                RandomPosition = true
            };
            Bitmap bitmap = coder.CreateImage(4, out string code);
            string id = _verifyCodeService.SetCode(code);
            return _verifyCodeService.GetImageString(bitmap, id);
        }
        #endregion
        #region "验证验证码的有效性，只作为前端Ajax验证，验证成功不移除验证码，验证码仍需传到后端进行再次验证"
        /// <summary>
        /// 验证验证码的有效性，只作为前端Ajax验证，验证成功不移除验证码，验证码仍需传到后端进行再次验证
        /// </summary>
        /// <param name="code">验证码字符串</param>
        /// <param name="id">验证码编号</param>
        /// <returns>是否无效</returns>
        [HttpGet]
        [ModuleInfo]
        [Description("验证验证码的有效性")]
        public bool CheckVerifyCode(string code, string id)
        {
            if (code.IsMissing() || id.IsMissing())
            {
                return true;
            }
            return _verifyCodeService.CheckCode(code, id, false);
        }
        #endregion

        #region "获取系统信息"
        /// <summary>
        /// 获取系统信息
        /// </summary>
        /// <returns>系统信息</returns>
        [HttpGet]
        [ModuleInfo]
        [Description("系统信息")]
        public object SystemInfo()
        {
            IServiceProvider provider = HttpContext.RequestServices;

            dynamic info = new ExpandoObject();
            info.Packs = provider.GetAllPacks().Select(m => new
            {
                m.GetType().Name,
                Class = m.GetType().FullName,
                Level = m.Level.ToString(),
                m.Order,
                m.IsEnabled
            }).ToList();

            string cliVersion = AssemblyExtensions.GetCliVersion();
            string eaCloudVersion = Assembly.GetExecutingAssembly().GetProductVersion();

            info.Object = new
            {
                Message = "WebApi 数据服务已启动",
                CliVersion = cliVersion,
                EaCloudVersion = eaCloudVersion
            };

            return info;
        }
        #endregion
        #endregion

    }
    #endregion

}
